summaryrefslogtreecommitdiff
path: root/nuttx/graphics
diff options
context:
space:
mode:
authorGregory Nutt <gnutt@nuttx.org>2014-09-20 15:01:50 -0600
committerGregory Nutt <gnutt@nuttx.org>2014-09-20 15:01:50 -0600
commitc9dc40dc7348d137fa260c05395ad0c5f396d441 (patch)
tree9a3de167a5d1be1a9edbc11da5c05322eb6b65ae /nuttx/graphics
parent53287415d45ecb9402fe7d838e040c9309120a68 (diff)
downloadnuttx-c9dc40dc7348d137fa260c05395ad0c5f396d441.tar.gz
nuttx-c9dc40dc7348d137fa260c05395ad0c5f396d441.tar.bz2
nuttx-c9dc40dc7348d137fa260c05395ad0c5f396d441.zip
Change all occurrences of NxConsole to NxTerm
Diffstat (limited to 'nuttx/graphics')
-rw-r--r--nuttx/graphics/Kconfig20
-rw-r--r--nuttx/graphics/Makefile10
-rw-r--r--nuttx/graphics/README.txt24
-rw-r--r--nuttx/graphics/nxterm/Make.defs (renamed from nuttx/graphics/nxconsole/Make.defs)2
-rw-r--r--nuttx/graphics/nxterm/nx_register.c (renamed from nuttx/graphics/nxconsole/nx_register.c)8
-rw-r--r--nuttx/graphics/nxterm/nxcon_driver.c (renamed from nuttx/graphics/nxconsole/nxcon_driver.c)2
-rw-r--r--nuttx/graphics/nxterm/nxcon_font.c (renamed from nuttx/graphics/nxconsole/nxcon_font.c)2
-rw-r--r--nuttx/graphics/nxterm/nxcon_internal.h (renamed from nuttx/graphics/nxconsole/nxcon_internal.h)14
-rw-r--r--nuttx/graphics/nxterm/nxcon_kbdin.c (renamed from nuttx/graphics/nxconsole/nxcon_kbdin.c)14
-rw-r--r--nuttx/graphics/nxterm/nxcon_putc.c (renamed from nuttx/graphics/nxconsole/nxcon_putc.c)2
-rw-r--r--nuttx/graphics/nxterm/nxcon_redraw.c (renamed from nuttx/graphics/nxconsole/nxcon_redraw.c)4
-rw-r--r--nuttx/graphics/nxterm/nxcon_register.c (renamed from nuttx/graphics/nxconsole/nxcon_register.c)6
-rw-r--r--nuttx/graphics/nxterm/nxcon_scroll.c (renamed from nuttx/graphics/nxconsole/nxcon_scroll.c)2
-rw-r--r--nuttx/graphics/nxterm/nxcon_sem.c (renamed from nuttx/graphics/nxconsole/nxcon_sem.c)2
-rw-r--r--nuttx/graphics/nxterm/nxcon_unregister.c (renamed from nuttx/graphics/nxconsole/nxcon_unregister.c)6
-rw-r--r--nuttx/graphics/nxterm/nxcon_vt100.c (renamed from nuttx/graphics/nxconsole/nxcon_vt100.c)2
-rw-r--r--nuttx/graphics/nxterm/nxtk_register.c (renamed from nuttx/graphics/nxconsole/nxtk_register.c)8
-rw-r--r--nuttx/graphics/nxterm/nxtool_register.c (renamed from nuttx/graphics/nxconsole/nxtool_register.c)8
18 files changed, 68 insertions, 68 deletions
diff --git a/nuttx/graphics/Kconfig b/nuttx/graphics/Kconfig
index 83c62b454..0b21d997a 100644
--- a/nuttx/graphics/Kconfig
+++ b/nuttx/graphics/Kconfig
@@ -358,17 +358,17 @@ config NXFONT_SERIF38X49B
endmenu
menuconfig NXTERM
- bool "NxConsole"
+ bool "NxTerm"
default n
---help---
- Enables building of the NxConsole driver.
+ Enables building of the NxTerm driver.
if NXTERM
-comment "NxConsole Output Text/Graphics Options"
+comment "NxTerm Output Text/Graphics Options"
config NXTERM_BPP
- int "NxConsole BPP"
+ int "NxTerm BPP"
default 1 if !NX_DISABLE_1BPP
default 2 if !NX_DISABLE_2BPP
default 4 if !NX_DISABLE_4BPP
@@ -377,7 +377,7 @@ config NXTERM_BPP
default 24 if !NX_DISABLE_24BPP
default 32 if !NX_DISABLE_32BPP
---help---
- Currently, NxConsole supports only a single pixel depth. This
+ Currently, NxTerm supports only a single pixel depth. This
configuration setting must be provided to support that single pixel depth.
Default: The smallest enabled pixel depth. (see NX_DISABLE_*BPP)
@@ -391,7 +391,7 @@ config NXTERM_MXCHARS
int "Max Characters on Display"
default 128
---help---
- NxConsole needs to remember every character written to the console so
+ NxTerm needs to remember every character written to the console so
that it can redraw the window. This setting determines the size of some
internal memory allocations used to hold the character data. Default: 128.
@@ -399,7 +399,7 @@ config NXTERM_CACHESIZE
int "Font Cache Size"
default 16
---help---
- NxConsole supports caching of rendered fonts. This font caching is required
+ NxTerm supports caching of rendered fonts. This font caching is required
for two reasons: (1) First, it improves text performance, but more
importantly (2) it preserves the font memory. Since the NX server runs on
a separate server thread, it requires that the rendered font memory persist
@@ -407,11 +407,11 @@ config NXTERM_CACHESIZE
cache would be quite large if all fonts were saved. The NXTERM_CACHESIZE
setting will control the size of the font cache (in number of glyphs). Only that
number of the most recently used glyphs will be retained. Default: 16.
- NOTE: There can still be a race condition between the NxConsole driver and the
+ NOTE: There can still be a race condition between the NxTerm driver and the
NX task. If you every see character corruption (especially when printing
a lot of data or scrolling), then increasing the value of NXTERM_CACHESIZE
is something that you should try. Alternatively, you can reduce the size of
- MQ_MAXMSGSIZE which will force NxConsole task to pace the server task.
+ MQ_MAXMSGSIZE which will force NxTerm task to pace the server task.
NXTERM_CACHESIZE should be larger than MQ_MAXMSGSIZE in any event.
config NXTERM_LINESEPARATION
@@ -428,7 +428,7 @@ config NXTERM_NOWRAP
of the window. This setting can be defining to change this behavior so
that the text is simply truncated until a new line is encountered.
-comment "NxConsole Input options"
+comment "NxTerm Input options"
config NXTERM_NXKBDIN
bool "NX KBD input"
diff --git a/nuttx/graphics/Makefile b/nuttx/graphics/Makefile
index 368f236e3..c66f68a1b 100644
--- a/nuttx/graphics/Makefile
+++ b/nuttx/graphics/Makefile
@@ -60,9 +60,9 @@ CFLAGS += ${shell $(INCDIR) $(INCDIROPT) "$(CC)" $(TOPDIR)/graphics/nxsu}
endif
ifeq ($(CONFIG_NXTERM),y)
-include nxconsole/Make.defs
-DEPPATH += --dep-path nxconsole
-CFLAGS += ${shell $(INCDIR) $(INCDIROPT) "$(CC)" $(TOPDIR)/graphics/nxconsole}
+include nxterm/Make.defs
+DEPPATH += --dep-path nxterm
+CFLAGS += ${shell $(INCDIR) $(INCDIROPT) "$(CC)" $(TOPDIR)/graphics/nxterm}
endif
ASRCS = $(NXGLIB_ASRCS) $(NXBE_ASRCS) $(NX_ASRCS) $(NXTK_ASRCS) $(NXCON_ASRCS)
@@ -77,9 +77,9 @@ OBJS = $(AOBJS) $(COBJS)
BIN = libgraphics$(LIBEXT)
ifeq ($(CONFIG_NX_MULTIUSER),y)
-VPATH = nxglib:nxbe:nxmu:nxconsole
+VPATH = nxglib:nxbe:nxmu:nxterm
else
-VPATH = nxglib:nxbe:nxsu:nxconsole
+VPATH = nxglib:nxbe:nxsu:nxterm
endif
all: mklibgraphics
diff --git a/nuttx/graphics/README.txt b/nuttx/graphics/README.txt
index e025808ee..cfc0e42de 100644
--- a/nuttx/graphics/README.txt
+++ b/nuttx/graphics/README.txt
@@ -34,10 +34,10 @@ at the present, but here is the longer term roadmap:
and without NXTOOLKIT for raw access to window memory.
NXGLIB - Low level graphics utilities and direct framebuffer rendering logic.
NX is built on top of NXGLIB.
- NxConsole - NxConsole is a write-only character device that is built on top of
+ NxTerm - NxTerm is a write-only character device that is built on top of
an NX window. This character device can be used to provide stdout
and stderr and, hence, can provide the output side of NuttX console.
- NxConsole is only available when the multi-user NX implementation is
+ NxTerm is only available when the multi-user NX implementation is
selected (CONFIG_NX_MULTIUSERs).
@@ -351,26 +351,26 @@ CONFIG_NXFONT_SERIF38X49B
This option enables support for a large, 38x49 bold font (with serifs)
(font ID FONTID_SERIF38X49B == 13).
-NxConsole Configuration Settings
+NxTerm Configuration Settings
--------------------------------
CONFIG_NXTERM
- Enables building of the NxConsole driver.
+ Enables building of the NxTerm driver.
-NxConsole output text/graphics options:
+NxTerm output text/graphics options:
CONFIG_NXTERM_BPP
- Currently, NxConsole supports only a single pixel depth. This
+ Currently, NxTerm supports only a single pixel depth. This
configuration setting must be provided to support that single pixel depth.
Default: The smallest enabled pixel depth. (see CONFIG_NX_DISABLE_*BPP)
CONFIG_NXTERM_CURSORCHAR
The bitmap code to use as the cursor. Default '_'
CONFIG_NXTERM_MXCHARS
- NxConsole needs to remember every character written to the console so
+ NxTerm needs to remember every character written to the console so
that it can redraw the window. This setting determines the size of some
internal memory allocations used to hold the character data. Default: 128.
CONFIG_NXTERM_CACHESIZE
- NxConsole supports caching of rendered fonts. This font caching is required
+ NxTerm supports caching of rendered fonts. This font caching is required
for two reasons: (1) First, it improves text performance, but more
importantly (2) it preserves the font memory. Since the NX server runs on
a separate server thread, it requires that the rendered font memory persist
@@ -378,11 +378,11 @@ CONFIG_NXTERM_CACHESIZE
cache would be quite large if all fonts were saved. The CONFIG_NXTERM_CACHESIZE
setting will control the size of the font cache (in number of glyphs). Only that
number of the most recently used glyphs will be retained. Default: 16.
- NOTE: There can still be a race condition between the NxConsole driver and the
+ NOTE: There can still be a race condition between the NxTerm driver and the
NX task. If you every see character corruption (especially when printing
a lot of data or scrolling), then increasing the value of CONFIG_NXTERM_CACHESIZE
is something that you should try. Alternatively, you can reduce the size of
- CONFIG_MQ_MAXMSGSIZE which will force NxConsole task to pace the server task.
+ CONFIG_MQ_MAXMSGSIZE which will force NxTerm task to pace the server task.
CONFIG_NXTERM_CACHESIZE should be larger than CONFIG_MQ_MAXMSGSIZE in any event.
CONFIG_NXTERM_LINESEPARATION
This the space (in rows) between each row of test. Default: 0
@@ -391,7 +391,7 @@ CONFIG_NXTERM_NOWRAP
of the window. This setting can be defining to change this behavior so
that the text is simply truncated until a new line is encountered.
-NxConsole Input options
+NxTerm Input options
CONFIG_NXTERM_NXKBDIN
Take input from the NX keyboard input callback. By default, keyboard
@@ -399,7 +399,7 @@ CONFIG_NXTERM_NXKBDIN
the interface nxcon_kdbin() is enabled. That interface may be driven
by window callback functions so that keyboard input *only* goes to the
top window.
-CONFIG__NXCONSOLE_KBDBUFSIZE
+CONFIG__NXTERM_KBDBUFSIZE
If CONFIG_NXTERM_NXKBDIN is enabled, then this value may be used to
define the size of the per-window keyboard input buffer. Default: 16
CONFIG_NXTERM_NPOLLWAITERS
diff --git a/nuttx/graphics/nxconsole/Make.defs b/nuttx/graphics/nxterm/Make.defs
index 3dc9c79a1..7a44ba263 100644
--- a/nuttx/graphics/nxconsole/Make.defs
+++ b/nuttx/graphics/nxterm/Make.defs
@@ -1,5 +1,5 @@
############################################################################
-# graphics/nxconsole/Make.defs
+# graphics/nxterm/Make.defs
#
# Copyright (C) 2012 Gregory Nutt. All rights reserved.
# Author: Gregory Nutt <gnutt@nuttx.org>
diff --git a/nuttx/graphics/nxconsole/nx_register.c b/nuttx/graphics/nxterm/nx_register.c
index 64eb878d9..ed84d3d28 100644
--- a/nuttx/graphics/nxconsole/nx_register.c
+++ b/nuttx/graphics/nxterm/nx_register.c
@@ -1,5 +1,5 @@
/****************************************************************************
- * nuttx/graphics/nxconsole/nx_register.c
+ * nuttx/graphics/nxterm/nx_register.c
*
* Copyright (C) 2012 Gregory Nutt. All rights reserved.
* Author: Gregory Nutt <gnutt@nuttx.org>
@@ -40,7 +40,7 @@
#include <nuttx/config.h>
#include <nuttx/nx/nx.h>
-#include <nuttx/nx/nxconsole.h>
+#include <nuttx/nx/nxterm.h>
#include "nxcon_internal.h"
@@ -186,8 +186,8 @@ static int nxcon_bitmap(FAR struct nxcon_state_s *priv,
*
****************************************************************************/
-NXCONSOLE nx_register(NXWINDOW hwnd, FAR struct nxcon_window_s *wndo, int minor)
+NXTERM nx_register(NXWINDOW hwnd, FAR struct nxcon_window_s *wndo, int minor)
{
- return nxcon_register((NXCONSOLE)hwnd, wndo, &g_nxops, minor);
+ return nxcon_register((NXTERM)hwnd, wndo, &g_nxops, minor);
}
diff --git a/nuttx/graphics/nxconsole/nxcon_driver.c b/nuttx/graphics/nxterm/nxcon_driver.c
index 0fa6f7400..5132183b2 100644
--- a/nuttx/graphics/nxconsole/nxcon_driver.c
+++ b/nuttx/graphics/nxterm/nxcon_driver.c
@@ -1,5 +1,5 @@
/****************************************************************************
- * nuttx/graphics/nxconsole/nxcon_driver.c
+ * nuttx/graphics/nxterm/nxcon_driver.c
*
* Copyright (C) 2012 Gregory Nutt. All rights reserved.
* Author: Gregory Nutt <gnutt@nuttx.org>
diff --git a/nuttx/graphics/nxconsole/nxcon_font.c b/nuttx/graphics/nxterm/nxcon_font.c
index 5d44af36a..310985ec4 100644
--- a/nuttx/graphics/nxconsole/nxcon_font.c
+++ b/nuttx/graphics/nxterm/nxcon_font.c
@@ -1,5 +1,5 @@
/****************************************************************************
- * nuttx/graphics/nxconsole/nxcon_font.c
+ * nuttx/graphics/nxterm/nxcon_font.c
*
* Copyright (C) 2012 Gregory Nutt. All rights reserved.
* Author: Gregory Nutt <gnutt@nuttx.org>
diff --git a/nuttx/graphics/nxconsole/nxcon_internal.h b/nuttx/graphics/nxterm/nxcon_internal.h
index 1f66c119b..9bee64c3e 100644
--- a/nuttx/graphics/nxconsole/nxcon_internal.h
+++ b/nuttx/graphics/nxterm/nxcon_internal.h
@@ -1,5 +1,5 @@
/****************************************************************************
- * nuttx/graphics/nxconsole/nxcon_internal.h
+ * nuttx/graphics/nxterm/nxcon_internal.h
*
* Copyright (C) 2012 Gregory Nutt. All rights reserved.
* Author: Gregory Nutt <gnutt@nuttx.org>
@@ -33,8 +33,8 @@
*
****************************************************************************/
-#ifndef __GRAPHICS_NXCONSOLE_NXCON_INTERNAL_H
-#define __GRAPHICS_NXCONSOLE_NXCON_INTERNAL_H
+#ifndef __GRAPHICS_NXTERM_NXCON_INTERNAL_H
+#define __GRAPHICS_NXTERM_NXCON_INTERNAL_H
/****************************************************************************
* Included Files
@@ -50,12 +50,12 @@
#include <nuttx/nx/nx.h>
#include <nuttx/nx/nxtk.h>
#include <nuttx/nx/nxfonts.h>
-#include <nuttx/nx/nxconsole.h>
+#include <nuttx/nx/nxterm.h>
/****************************************************************************
* Definitions
****************************************************************************/
-/* NxConsole Definitions ****************************************************/
+/* NxTerm Definitions ****************************************************/
/* Bitmap flags */
#define BMFLAGS_NOGLYPH (1 << 0) /* No glyph available, use space */
@@ -216,7 +216,7 @@ int nxcon_sempost(FAR struct nxcon_state_s *priv);
/* Common device registration */
-FAR struct nxcon_state_s *nxcon_register(NXCONSOLE handle,
+FAR struct nxcon_state_s *nxcon_register(NXTERM handle,
FAR struct nxcon_window_s *wndo, FAR const struct nxcon_operations_s *ops,
int minor);
@@ -251,4 +251,4 @@ void nxcon_hidecursor(FAR struct nxcon_state_s *priv);
void nxcon_scroll(FAR struct nxcon_state_s *priv, int scrollheight);
-#endif /* __GRAPHICS_NXCONSOLE_NXCON_INTERNAL_H */
+#endif /* __GRAPHICS_NXTERM_NXCON_INTERNAL_H */
diff --git a/nuttx/graphics/nxconsole/nxcon_putc.c b/nuttx/graphics/nxterm/nxcon_putc.c
index f612b2eb3..aa0c8f8a3 100644
--- a/nuttx/graphics/nxconsole/nxcon_putc.c
+++ b/nuttx/graphics/nxterm/nxcon_putc.c
@@ -1,5 +1,5 @@
/****************************************************************************
- * nuttx/graphics/nxconsole/nxcon_putc.c
+ * nuttx/graphics/nxterm/nxcon_putc.c
*
* Copyright (C) 2012 Gregory Nutt. All rights reserved.
* Author: Gregory Nutt <gnutt@nuttx.org>
diff --git a/nuttx/graphics/nxconsole/nxcon_redraw.c b/nuttx/graphics/nxterm/nxcon_redraw.c
index b1363454c..5ecb4ed48 100644
--- a/nuttx/graphics/nxconsole/nxcon_redraw.c
+++ b/nuttx/graphics/nxterm/nxcon_redraw.c
@@ -1,5 +1,5 @@
/****************************************************************************
- * nuttx/graphics/nxconsole/nxcon_bkgd.c
+ * nuttx/graphics/nxterm/nxcon_bkgd.c
*
* Copyright (C) 2012 Gregory Nutt. All rights reserved.
* Author: Gregory Nutt <gnutt@nuttx.org>
@@ -98,7 +98,7 @@
*
****************************************************************************/
-void nxcon_redraw(NXCONSOLE handle, FAR const struct nxgl_rect_s *rect, bool more)
+void nxcon_redraw(NXTERM handle, FAR const struct nxgl_rect_s *rect, bool more)
{
FAR struct nxcon_state_s *priv;
int ret;
diff --git a/nuttx/graphics/nxconsole/nxcon_register.c b/nuttx/graphics/nxterm/nxcon_register.c
index 67859922f..c2ddca8f1 100644
--- a/nuttx/graphics/nxconsole/nxcon_register.c
+++ b/nuttx/graphics/nxterm/nxcon_register.c
@@ -1,5 +1,5 @@
/****************************************************************************
- * nuttx/graphics/nxconsole/nxcon_register.c
+ * nuttx/graphics/nxterm/nxcon_register.c
*
* Copyright (C) 2012 Gregory Nutt. All rights reserved.
* Author: Gregory Nutt <gnutt@nuttx.org>
@@ -73,7 +73,7 @@
****************************************************************************/
FAR struct nxcon_state_s *
- nxcon_register(NXCONSOLE handle, FAR struct nxcon_window_s *wndo,
+ nxcon_register(NXTERM handle, FAR struct nxcon_window_s *wndo,
FAR const struct nxcon_operations_s *ops, int minor)
{
FAR struct nxcon_state_s *priv;
@@ -152,7 +152,7 @@ FAR struct nxcon_state_s *
{
gdbg("Failed to register %s\n", devname);
}
- return (NXCONSOLE)priv;
+ return (NXTERM)priv;
errout:
kmm_free(priv);
diff --git a/nuttx/graphics/nxconsole/nxcon_scroll.c b/nuttx/graphics/nxterm/nxcon_scroll.c
index 7c645976c..508d26ec3 100644
--- a/nuttx/graphics/nxconsole/nxcon_scroll.c
+++ b/nuttx/graphics/nxterm/nxcon_scroll.c
@@ -1,5 +1,5 @@
/****************************************************************************
- * nuttx/graphics/nxconsole/nxcon_scroll.c
+ * nuttx/graphics/nxterm/nxcon_scroll.c
*
* Copyright (C) 2012, 2014 Gregory Nutt. All rights reserved.
* Author: Gregory Nutt <gnutt@nuttx.org>
diff --git a/nuttx/graphics/nxconsole/nxcon_sem.c b/nuttx/graphics/nxterm/nxcon_sem.c
index 26036c2f4..97d09c2b6 100644
--- a/nuttx/graphics/nxconsole/nxcon_sem.c
+++ b/nuttx/graphics/nxterm/nxcon_sem.c
@@ -1,5 +1,5 @@
/****************************************************************************
- * nuttx/graphics/nxconsole/nxcon_sem.c
+ * nuttx/graphics/nxterm/nxcon_sem.c
*
* Copyright (C) 2012 Gregory Nutt. All rights reserved.
* Author: Gregory Nutt <gnutt@nuttx.org>
diff --git a/nuttx/graphics/nxconsole/nxcon_unregister.c b/nuttx/graphics/nxterm/nxcon_unregister.c
index 2ebfdf7ec..a502eadd4 100644
--- a/nuttx/graphics/nxconsole/nxcon_unregister.c
+++ b/nuttx/graphics/nxterm/nxcon_unregister.c
@@ -1,5 +1,5 @@
/****************************************************************************
- * nuttx/graphics/nxconsole/nxcon_unregister.c
+ * nuttx/graphics/nxterm/nxcon_unregister.c
*
* Copyright (C) 2012 Gregory Nutt. All rights reserved.
* Author: Gregory Nutt <gnutt@nuttx.org>
@@ -46,7 +46,7 @@
#include <errno.h>
#include <nuttx/kmalloc.h>
-#include <nuttx/nx/nxconsole.h>
+#include <nuttx/nx/nxterm.h>
#include "nxcon_internal.h"
@@ -85,7 +85,7 @@
*
****************************************************************************/
-void nxcon_unregister(NXCONSOLE handle)
+void nxcon_unregister(NXTERM handle)
{
FAR struct nxcon_state_s *priv;
char devname[NX_DEVNAME_SIZE];
diff --git a/nuttx/graphics/nxconsole/nxcon_vt100.c b/nuttx/graphics/nxterm/nxcon_vt100.c
index 3e3374dce..cc8796341 100644
--- a/nuttx/graphics/nxconsole/nxcon_vt100.c
+++ b/nuttx/graphics/nxterm/nxcon_vt100.c
@@ -1,5 +1,5 @@
/****************************************************************************
- * nuttx/graphics/nxconsole/nxcon_vt100.c
+ * nuttx/graphics/nxterm/nxcon_vt100.c
*
* Copyright (C) 2012 Gregory Nutt. All rights reserved.
* Author: Gregory Nutt <gnutt@nuttx.org>
diff --git a/nuttx/graphics/nxconsole/nxtk_register.c b/nuttx/graphics/nxterm/nxtk_register.c
index b3c17e864..df392961e 100644
--- a/nuttx/graphics/nxconsole/nxtk_register.c
+++ b/nuttx/graphics/nxterm/nxtk_register.c
@@ -1,5 +1,5 @@
/****************************************************************************
- * nuttx/graphics/nxconsole/nxtk_register.c
+ * nuttx/graphics/nxterm/nxtk_register.c
*
* Copyright (C) 2012 Gregory Nutt. All rights reserved.
* Author: Gregory Nutt <gnutt@nuttx.org>
@@ -40,7 +40,7 @@
#include <nuttx/config.h>
#include <nuttx/nx/nxtk.h>
-#include <nuttx/nx/nxconsole.h>
+#include <nuttx/nx/nxterm.h>
#include "nxcon_internal.h"
@@ -186,7 +186,7 @@ static int nxtkcon_bitmap(FAR struct nxcon_state_s *priv,
*
****************************************************************************/
-NXCONSOLE nxtk_register(NXTKWINDOW hfwnd, FAR struct nxcon_window_s *wndo, int minor)
+NXTERM nxtk_register(NXTKWINDOW hfwnd, FAR struct nxcon_window_s *wndo, int minor)
{
- return nxcon_register((NXCONSOLE)hfwnd, wndo, &g_nxtkops, minor);
+ return nxcon_register((NXTERM)hfwnd, wndo, &g_nxtkops, minor);
}
diff --git a/nuttx/graphics/nxconsole/nxtool_register.c b/nuttx/graphics/nxterm/nxtool_register.c
index d7666e523..631339a17 100644
--- a/nuttx/graphics/nxconsole/nxtool_register.c
+++ b/nuttx/graphics/nxterm/nxtool_register.c
@@ -1,5 +1,5 @@
/****************************************************************************
- * nuttx/graphics/nxconsole/nxtool_register.c
+ * nuttx/graphics/nxterm/nxtool_register.c
*
* Copyright (C) 2012 Gregory Nutt. All rights reserved.
* Author: Gregory Nutt <gnutt@nuttx.org>
@@ -40,7 +40,7 @@
#include <nuttx/config.h>
#include <nuttx/nx/nxtk.h>
-#include <nuttx/nx/nxconsole.h>
+#include <nuttx/nx/nxterm.h>
#include "nxcon_internal.h"
@@ -188,8 +188,8 @@ static int nxtool_bitmap(FAR struct nxcon_state_s *priv,
*
****************************************************************************/
-NXCONSOLE nxtool_register(NXTKWINDOW hfwnd, FAR struct nxcon_window_s *wndo, int minor)
+NXTERM nxtool_register(NXTKWINDOW hfwnd, FAR struct nxcon_window_s *wndo, int minor)
{
- return nxcon_register((NXCONSOLE)hfwnd, wndo, &g_nxtoolops, minor);
+ return nxcon_register((NXTERM)hfwnd, wndo, &g_nxtoolops, minor);
}
diff --git a/nuttx/graphics/nxconsole/nxcon_kbdin.c b/nuttx/graphics/nxterm/nxcon_kbdin.c
index fa7990a71..4cac68edf 100644
--- a/nuttx/graphics/nxconsole/nxcon_kbdin.c
+++ b/nuttx/graphics/nxterm/nxcon_kbdin.c
@@ -1,5 +1,5 @@
/****************************************************************************
- * nuttx/graphics/nxconsole/nxcon_kbdin.c
+ * nuttx/graphics/nxterm/nxcon_kbdin.c
*
* Copyright (C) 2012 Gregory Nutt. All rights reserved.
* Author: Gregory Nutt <gnutt@nuttx.org>
@@ -106,7 +106,7 @@ static void nxcon_pollnotify(FAR struct nxcon_state_s *priv, pollevent_t eventse
* Name: nxcon_read
*
* Description:
* The optional NxConsole read method
*
****************************************************************************/
@@ -373,15 +373,15 @@ errout:
*
* Description:
* This function should be driven by the window kbdin callback function
* (see nx.h). When the NxConsole is the top window and keyboard input is
* received on the top window, that window callback should be directed to
* this function. This function will buffer the keyboard data and makE
* it available to the NxConsole as stdin.
*
- * If CONFIG_NXTERM_NXKBDIN is not selected, then the NxConsole will
+ * If CONFIG_NXTERM_NXKBDIN is not selected, then the NxTerm will
* receive its input from stdin (/dev/console). This works great but
* cannot be shared between different windows. Chaos will ensue if you
- * try to support multiple NxConsole windows without CONFIG_NXTERM_NXKBDIN
+ * try to support multiple NxTerm windows without CONFIG_NXTERM_NXKBDIN
*
* Input Parameters:
* handle - A handle previously returned by nx_register, nxtk_register, or
@@ -394,7 +394,7 @@ errout:
*
****************************************************************************/
-void nxcon_kbdin(NXCONSOLE handle, FAR const uint8_t *buffer, uint8_t buflen)
+void nxcon_kbdin(NXTERM handle, FAR const uint8_t *buffer, uint8_t buflen)
{
FAR struct nxcon_state_s *priv;
ssize_t nwritten;
@@ -106,7 +106,7 @@ static void nxcon_pollnotify(FAR struct nxcon_state_s *priv, pollevent_t eventse
*
* Description:
- * The optional NxConsole read method
+ * The optional NxTerm read method
*
****************************************************************************/
@@ -373,15 +373,15 @@ errout:
* Description:
* This function should be driven by the window kbdin callback function
- * (see nx.h). When the NxConsole is the top window and keyboard input is
+ * (see nx.h). When the NxTerm is the top window and keyboard input is
* received on the top window, that window callback should be directed to
* this function. This function will buffer the keyboard data and makE
@@ -373,15 +373,15 @@ errout:
* received on the top window, that window callback should be directed to
* this function. This function will buffer the keyboard data and makE
- * it available to the NxConsole as stdin.
+ * it available to the NxTerm as stdin.
*